/*
    scconfig - helper functions for detecting parser libs
    Copyright (C) 2009  Tibor Palinkas

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

		Project page: http://repo.hu/projects/scconfig
		Contact via email: scconfig [at] igor2.repo.hu
*/

#include "parser.h"
#include <assert.h>
#include "find.h"

void deps_parser_init()
{
	dep_add("libs/parser/expat/ldflags",       find_parser_expat);
}

int try_parser(int logdepth, const char *prefix, const char *test_c, char *cflags, char *ldflags)
{
	char *out = NULL;
	char *tmp;

	logprintf(logdepth, "trying '%s' and '%s'\n", cflags, ldflags);
	if (compile_run(logdepth+1, test_c, NULL, cflags, ldflags, &out) == 0) {
		if (target_emu_fail(out) || (strncmp(out, "OK", 2) == 0)) {
			free(out);

			if (*cflags == '+')
				cflags++;
			if (*ldflags == '+')
				ldflags++;

			tmp = malloc(strlen(prefix) + 32);
			sprintf(tmp, "%s/cflags", prefix);
			put(tmp, cflags);
			sprintf(tmp, "%s/ldflags", prefix);
			put(tmp, ldflags);
			sprintf(tmp, "%s/presents", prefix);
			put(tmp, "true");
			report("OK ('%s' and '%s')\n", cflags, ldflags);

			free(tmp);
			return 1;
		}
		free(out);
	}
	return 0;
}

